# gcc 4.8 doesn't seem to like bluetooth headers with strict
%bcond_with strict

# the test scripts seem to be broken
%bcond_with tests

# whether to do a verbose build
%bcond_without verbose_build
%if %{with verbose_build}
%global _verbose -v
%else
%global _verbose %{nil}
%endif

%global backends jack,alsa,dummy

%global man_langs_encodings :UTF-8 es:UTF-8 fr:ISO-8859-1 ru:KOI8-R

# Don't generate provides for internal shared objects and plugins
%global internal_libs_re (ardour.*|audiographer|canvas|evoral|gtkmm2ext|jack_audiobackend|midipp|pan[12]in2out|panbalance|panvbap|pbd|qmdsp|timecode)
%global __provides_exclude_from ^%{_libdir}/(%{name}|lv2)/.*$
%global __requires_exclude ^lib%{internal_libs_re}\.so.*$

# This package is named ardour4 to allow parallel installation with older versions of Ardour (2 and 3).
Name:       ardour4
Version:    4.0.0

Release:    2%{?dist}
Summary:    Digital Audio Workstation

Group:      Applications/Multimedia
License:    GPLv2+
URL:        http://ardour.org
# Not available via direct download. Download via
# http://ardour.org/download.html
Source0:    Ardour-%{version}.tar.bz2
# BSD 2/3-clause licenses used in some code files
Source1:    LICENSING
# Don't install static library libsmf.a
# https://github.com/Ardour/ardour/pull/111
Patch0:     ardour4-4.0.0-dont-install-libsmf-a.patch

BuildRequires:  alsa-lib-devel
BuildRequires:  aubio-devel >= 0.3.2
BuildRequires:  bluez-libs-devel
BuildRequires:  boost-devel >= 1.39
BuildRequires:  cppunit-devel >= 1.12.0
BuildRequires:  cwiid-devel >= 0.6.00
BuildRequires:  dbus-devel
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  fftw-devel
BuildRequires:  flac-devel >= 1.2.1
BuildRequires:  fontconfig
BuildRequires:  gettext
BuildRequires:  glib2-devel >= 2.14.0
BuildRequires:  glibmm24-devel >= 2.32.0
BuildRequires:  graphviz
BuildRequires:  gtk2-devel >= 2.18
BuildRequires:  gtkmm24-devel >= 2.18
BuildRequires:  jack-audio-connection-kit-devel >= 1.9.10
BuildRequires:  kernel-headers
BuildRequires:  libcurl-devel >= 7.0.0
BuildRequires:  libgnomecanvas-devel >= 2.30
BuildRequires:  libgnomecanvasmm26-devel >= 2.16
BuildRequires:  liblo-devel >= 0.24
BuildRequires:  liblrdf-devel >= 0.4.0
BuildRequires:  libltc-devel >= 1.1.1
BuildRequires:  libogg-devel >= 1.1.2
BuildRequires:  libsamplerate-devel >= 0.1.7
BuildRequires:  libsigc++20-devel >= 2.0
BuildRequires:  libsndfile-devel >= 1.0.18
BuildRequires:  libuuid-devel
BuildRequires:  libX11-devel >= 1.1
BuildRequires:  libxml2-devel
BuildRequires:  lilv-devel >= 0.14.0
BuildRequires:  lv2-devel >= 1.0.0
BuildRequires:  python
BuildRequires:  rubberband-devel >= 1.0
BuildRequires:  serd-devel >= 0.14.0
BuildRequires:  sord-devel >= 0.8.0
BuildRequires:  sratom-devel >= 0.2.0
BuildRequires:  suil-devel >= 0.6.0
BuildRequires:  taglib-devel >= 1.4
BuildRequires:  vamp-plugin-sdk-devel

Requires:       %{name}-audiobackend%{?_isa} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires:       google-droid-sans-mono-fonts

%description
Ardour is a multi-channel digital audio workstation, allowing users to record,
edit, mix and master audio and MIDI projects. It is targeted at audio
engineers, musicians, soundtrack editors and composers.

# This macro creates a backend subpackage.
#   %%backend_package <type> <backendname>
%define backend_package() \
%package %{1}backend-%{lua: print(string.lower(rpm.expand("%2")))}\
Summary:    %{2} %{1} backend for %{name}\
Group:      Applications/Multimedia\
Requires:   %{name}%{?_isa} = %{?epoch:%{epoch}:}%{version}-%{release}\
Provides:   %{name}-%{1}backend%{?_isa}\
\
%description %{1}backend-%{lua: print(string.lower(rpm.expand("%2")))}\
This package provides the %{2} %{1} backend for Ardour.\
\
%files %{1}backend-%{lua: print(string.lower(rpm.expand("%2")))}\
%{_libdir}/%{name}/backends/lib%{lua: print(string.lower(rpm.expand("%2")))}_%{1}backend.so

%backend_package audio ALSA
%backend_package audio JACK
%backend_package audio Dummy

%prep
%setup -q -n Ardour-%{version}
%patch0 -p1 -b .dont-install-libsmf-a

# use versionized name for all and reencode some man pages
for lang_enc in %{man_langs_encodings}; do
    lang="${lang_enc%%:*}"
    enc="${lang_enc#*:}"
    if [ -n "$lang" ]; then
        lang=".${lang}"
    fi
    fromfile="ardour.1${lang}"
    tofile="%{name}.1${lang}"
    iconv -f "$enc" -t UTF-8 "$fromfile" > "$tofile"
    touch -r "$fromfile" "$tofile"
done

cp %{SOURCE1} .

%build
export LC_ALL=en_US.UTF-8
./waf configure \
%if %{with strict}
    --strict \
%endif
%if %{with tests}
    --test \
%endif
    --prefix="%_prefix" \
    --bindir="%_bindir" \
    --configdir="%_sysconfdir" \
    --datadir="%_datadir" \
    --includedir="%_includedir" \
    --libdir="%_libdir" \
    --mandir="%_mandir" \
    --docdir="%_docdir" \
    --docs \
    --freedesktop \
    --lv2 \
    --lxvst \
    --nls \
    --noconfirm \
    --no-phone-home \
    --optimize \
%ifarch %ix86 x86_64
    --arch="%optflags -msse -mfpmath=sse -DUSE_XMMINTRIN" \
%else
    --arch="%optflags" \
%endif
    --use-external-libs \
    --with-backends=%{backends}

./waf build %{_verbose} %{?_smp_mflags}
./waf i18n %{_verbose} %{?_smp_mflags}

sed 's/=ardour3/=%{name}/g' < gtk2_ardour/ardour3.desktop.in > \
    gtk2_ardour/%{name}.desktop

%install
./waf --destdir=%{buildroot} install %{_verbose}

# ArdourMono.ttf is really Droid Sans Mono
ln -snf ../fonts/google-droid/DroidSansMono.ttf %{buildroot}%{_datadir}/%{name}/ArdourMono.ttf

# install man pages
install -d -m755 %{buildroot}%{_mandir}/man1
for lang_enc in %man_langs_encodings; do
    lang="${lang_enc%%:*}"
    if [ -n "$lang" ]; then
        _lang=".${lang}"
    else
        _lang=""
    fi
    fromfile="%{name}.1${_lang}"
    todir="%{buildroot}%{_mandir}/${lang}/man1"
    tofile="${todir}/%{name}.1"
    install -d -m755 "$todir"
    install -p -m644 "$fromfile" "$tofile"
done

# install icons to freedesktop locations
for s in 16 22 32 48 256 512; do
    mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps
    ln -s ../../../../%{name}/icons/ardour_icon_${s}px.png \
       %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/%{name}.png
done

# tweak and install desktop file
mkdir -p %{buildroot}%{_datadir}/applications/
desktop-file-install --dir %{buildroot}%{_datadir}/applications \
    --set-key=Name --set-value="Ardour %{version}" \
    --set-generic-name="Digital Audio Workstation" \
    --set-key=X-GNOME-FullName \
    --set-value="Ardour v%{version} (Digital Audio Workstation)" \
    --set-comment="Record, mix and master audio" \
    --remove-category=AudioEditing \
    --add-category=X-AudioEditing \
    gtk2_ardour/%{name}.desktop

# install mime entry
mkdir -p %{buildroot}%{_datadir}/mime/packages/
install -p -m 0644 gtk2_ardour/ardour3.xml %{buildroot}%{_datadir}/mime/packages/%{name}.xml

%find_lang %{name}
%find_lang gtk2_%{name}
%find_lang gtkmm2ext3

# Collect non-locale data files and (all) directories
find %{buildroot}%{_datadir}/%{name} | \
    sed 's|^%{buildroot}||g' | \
    while read f; do
        # *sigh*
        if [ "$f" = "${f/ /}" ]; then
            _f="$f"
        else
            _f="\"${f}\""
        fi

        if [ -d "%{buildroot}${f}" ]; then
            echo "%%dir ${_f}"
        else
            if [ "${f}" = "${f#%{_datadir}/%{name}/locale}" ]; then
                echo "${_f}"
            fi
        fi
    done > %{name}-datafiles.list

%if %{with tests}
%check
WAFTPATH="$PWD/doc/waft"
pushd libs/ardour
sh "$WAFTPATH" --targets=libardour-tests && ./run-tests.sh
popd
%endif

rm -f %{buildroot}%{_bindir}/run-tests

%post
/bin/touch --no-create %{_datadir}/icons/hicolor &> /dev/null || :
/bin/touch --no-create %{_datadir}/mime/packages &> /dev/null || :
/usr/bin/update-desktop-database &> /dev/null || :

%postun
/usr/bin/update-desktop-database &> /dev/null || :
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /bin/touch --no-create %{_datadir}/mime/packages &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
    /usr/bin/update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :

%files -f %{name}.lang -f gtk2_%{name}.lang -f gtkmm2ext3.lang -f %{name}-datafiles.list
%doc COPYING LICENSING
%{_bindir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}
%{_libdir}/%{name}
%exclude %{_libdir}/%{name}/backends/*
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man1/%{name}.1*
%{_mandir}/*/man1/%{name}.1*

%changelog
* Sun May 03 2015 Nils Philippsen <nils@redhat.com> - 4.0.0-2
- move audio backends into their own subpackages

* Fri May 01 2015 Nils Philippsen <nils@redhat.com> - 4.0.0-1
- don't install static library libsmf.a
- symlink rather than hardlink application icons

* Mon Apr 27 2015 Nils Philippsen <nils@redhat.com> - 4.0.0-0.2
- build alsa, dummy backends

* Thu Apr 23 2015 Nils Philippsen <nils@redhat.com> - 4.0.0-0.1
- version 4.0.0
